@@ -109,10 +109,13 @@ void UserManager::loadLoginDefs() {
             QByteArray line = file.readLine().trimmed();
             if(line.isEmpty() || line.startsWith('#'))
                 continue;
+#if (QT_VERSION >= QT_VERSION_CHECK(5,15,0))
+            QStringList parts = QString::fromUtf8(line).split(QRegExp(QSL("\\s")), Qt::SkipEmptyParts);
+#else
             QStringList parts = QString::fromUtf8(line).split(QRegExp(QSL("\\s")), QString::SkipEmptyParts);
+#endif
             if(parts.length() >= 2) {
                 QString& key = parts[0];
-                QString& val = parts[1];
                 if(key == QLatin1String("SYS_UID_MIN")) {
                 }
                 else if(key == QLatin1String("SYS_UID_MAX")) {
@@ -192,7 +195,7 @@ void UserManager::reload() {
     Q_EMIT changed();
 }
 
-void UserManager::onFileChanged(const QString &path) {
+void UserManager::onFileChanged(const QString & /*path*/) {
     // QFileSystemWatcher is very broken and has a ridiculous design.
     // we get "fileChanged()" when the file is deleted or modified,
     // but there is no way to distinguish them. If the file is deleted,
